#!/usr/bin/env python3
# -*- coding: utf-8, vim: expandtab:ts=4 -*-

"""
sono-board
Copyright (C) 2021  Sono Project

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

# imports: library
from dataclasses import dataclass, InitVar, field
import json
import os


@dataclass
class SoundboardItem:
    filename: str
    text: str


@dataclass
class Config:

    main_file_path: InitVar[str]

    _main_dir: str = None
    _data_dir: str = None

    board_name: str = None

    title: str = 'Soundboard'
    sound_items: list[SoundboardItem] = field(default_factory=list)

    def __post_init__(self, main_file_path: str):
        self._main_dir = os.path.split(os.path.abspath(main_file_path))[0]
        self._data_dir = os.path.join(self._main_dir, 'data')

    def data_path(self, *elements) -> str:
        return os.path.join(self._data_dir, *elements)

    def data_path_board(self, *elements) -> str:
        return os.path.join(self._data_dir, self.board_name, *elements)

    def load(self, name):

        self.board_name = name

        path = self.data_path(self.board_name, 'config.json')

        with open(path, 'rb') as config_file:
            config_json = json.load(config_file)

        self.title = config_json['title']

        self.sound_items = []
        for item in config_json['sounds']:
            self.sound_items.append(SoundboardItem(item['filename'], item['text']))
