#!/usr/bin/env python3
# -*- coding: utf-8, vim: expandtab:ts=4 -*-

"""
sono-board
Copyright (C) 2021  Sono Project

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

# imports: library
import logging

# imports: requirements
import pygame


class MixerInitError(Exception):
    pass


if not pygame.mixer:
    logging.warning('sound disabled')


def _load_mixer():

    if not pygame.mixer.get_init():
        pygame.mixer.init()

        if (mixer_init := pygame.mixer.get_init()) is not None:
            logging.info('Mixer initalized.')
            mixer_frequency, mixer_format, mixer_channels = mixer_init
            logging.info(f'frequency: {mixer_frequency}')
            logging.info(f'format:    {mixer_format}')
            logging.info(f'channels:  {mixer_channels}')
        else:
            raise MixerInitError('Mixer NOT initalized!')


def load_sound(path):

    class NoneSound:
        def play(self):
            pass

    if not pygame.mixer:
        return NoneSound()

    try:
        _load_mixer()
    except MixerInitError as exc:
        logging.warning(exc)
        return NoneSound()

    sound = pygame.mixer.Sound(path)

    return sound


def deinit() -> None:
    pygame.mixer.quit()
